@@ -1,7 +1,7 @@
 /**********************************************************************
  *  batchprocessing.cpp
  **********************************************************************
- * Copyright (C) 2020-2024 MX Authors
+ * Copyright (C) 2020 MX Authors
  *
  * Authors: Adrian
  *          MX Linux <http://mxlinux.org>
@@ -33,11 +33,11 @@
 using namespace std::chrono_literals;
 
 Batchprocessing::Batchprocessing(const QCommandLineParser &arg_parser, QObject *parent)
-    : QObject(parent),
-      Settings(arg_parser),
-      work(this)
+    : QObject(parent)
+    , Settings(arg_parser)
+    , work(this)
 {
-    connect(qApp, &QCoreApplication::aboutToQuit, this, [this] { work.cleanUp(); });
+    connect(qApp, &QCoreApplication::aboutToQuit, [this] { work.cleanUp(); });
     setConnections();
 
     if (!checkCompression()) {
@@ -48,28 +48,25 @@ Batchprocessing::Batchprocessing(const QCommandLineParser &arg_parser, QObject *
     }
 
     QString path = snapshot_dir;
-    qDebug() << "Free space:" << getFreeSpaceStrings(path.remove(QRegularExpression("/snapshot$")));
-    if (!arg_parser.isSet("month") && !arg_parser.isSet("override-size")) {
-        qDebug() << "Unused space:" << getUsedSpace();
-    }
+    getFreeSpaceStrings(path.remove(QRegularExpression(QStringLiteral("/snapshot$"))));
+    if (!arg_parser.isSet(QStringLiteral("month")) && !arg_parser.isSet(QStringLiteral("override-size")))
+        getUsedSpace();
 
     work.started = true;
     work.e_timer.start();
-    if (!checkSnapshotDir() || !checkTempDir()) {
+    if (!checkSnapshotDir() || !checkTempDir())
         work.cleanUp();
-    }
     otherExclusions();
     work.setupEnv();
-    if (!arg_parser.isSet("month") && !arg_parser.isSet("override-size")) {
+    if (!arg_parser.isSet(QStringLiteral("month")) && !arg_parser.isSet(QStringLiteral("override-size")))
         work.checkEnoughSpace();
-    }
     work.copyNewIso();
     work.savePackageList(snapshot_name);
 
     if (edit_boot_menu) {
         qDebug() << QObject::tr("The program will pause the build and open the boot menu in your text editor.");
         QString cmd = getEditor() + " \"" + work_dir + "/iso-template/boot/isolinux/isolinux.cfg\"";
-        Cmd().run(cmd);
+        shell->run(cmd);
     }
     disconnect(&timer, &QTimer::timeout, nullptr, nullptr);
     work.createIso(snapshot_name);
@@ -78,10 +75,10 @@ Batchprocessing::Batchprocessing(const QCommandLineParser &arg_parser, QObject *
 void Batchprocessing::setConnections()
 {
     connect(&timer, &QTimer::timeout, this, &Batchprocessing::progress);
-    connect(&work.shell, &Cmd::started, this, [this] { timer.start(500ms); });
-    connect(&work.shell, &Cmd::done, this, [this] { timer.stop(); });
-    connect(&work.shell, &Cmd::outputAvailable, this, [](const QString &out) { qDebug().noquote() << out; });
-    connect(&work.shell, &Cmd::errorAvailable, this, [](const QString &out) { qWarning().noquote() << out; });
+    connect(shell, &Cmd::started, [this] { timer.start(500ms); });
+    connect(shell, &Cmd::finished, [this] { timer.stop(); });
+    connect(shell, &Cmd::outputAvailable, [](const QString &out) { qDebug().noquote() << out; });
+    connect(shell, &Cmd::errorAvailable, [](const QString &out) { qWarning().noquote() << out; });
     connect(&work, &Work::message, [](const QString &out) { qDebug().noquote() << out; });
     connect(&work, &Work::messageBox,
             [](BoxType /*unused*/, const QString &title, const QString &msg) { qDebug().noquote() << title << msg; });
@@ -90,5 +87,6 @@ void Batchprocessing::setConnections()
 void Batchprocessing::progress()
 {
     static int i = 0;
-    qDebug() << "\033[2KProcessing command" << ((i++ % 2 == 1) ? "...\r" : "\r");
+    (i % 2 == 1) ? qDebug() << "\033[2KProcessing command...\r" : qDebug() << "\033[2KProcessing command\r";
+    ++i;
 }
